@@ -6,7 +6,7 @@ import click
 
 class ConfigParser:
     def __init__(self, config_name):
-        self.config = {}
+        self.config = None
         if os.environ.get("FREELDEP_CONFIG", ""):
             config_name = os.environ["FREELDEP_CONFIG"]
         elif os.environ.get("FREELDEP_HOME", ""):
@@ -23,7 +23,7 @@ class ConfigParser:
             )
 
     def get(self, section, name, default=None):
-        if section not in self.config.sections():
+        if self.config is None or section not in self.config.sections():
             return default
         return self.config[section].get(name, default)
 
